source/badges library

Classes

DynamicBadge
This class is used to create a badge with a label The label is limited to 4 characters, if the label is greater than 4 characters the label will be truncated