DynamicBadge class

Inheritance

Constructors

DynamicBadge({required int count, required Widget child, Color textColor = Colors.white, Color backgroundColor = Colors.redAccent, Key? key})
Constructor to create a badge with a counter, The counter is limited to 999, if the counter is greater than 999 the label will be "999+"
const
DynamicBadge.small({required Widget child, Color textColor = Colors.white, Color backgroundColor = Colors.redAccent, Key? key})
Constructor to create a badge with a small size Is a badge without label, sometimes is used to indicate that the icon has a notification
const

Properties

backgroundColor Color
final
child Widget
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
textColor Color
final
type BadgeType
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<DynamicBadge>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited