DynamicBadge class

This class is used to create a badge with a label The label is limited to 4 characters, if the label is greater than 4 characters the label will be truncated

Inheritance

Constructors

DynamicBadge({required String label, required double childSize, Color? textColor, Color? backgroundColor, AlignmentGeometry? alignment, Widget? child, Key? key})
const
DynamicBadge.counter({required int count, required double childSize, Color? textColor, Color? backgroundColor, AlignmentGeometry? alignment, Widget? child, Key? key})
Constructor to create a badge with a counter, The counter is limited to 999, if the counter is greater than 999 the label will be "999+"
const
DynamicBadge.small({required double childSize, AlignmentGeometry? alignment, Color? backgroundColor, Widget? child, Key? key})
Constructor to create a badge with a small size Is a badge without label, sometimes is used to indicate that the icon has a notification
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited