DynamicBadge.small constructor

const DynamicBadge.small({
  1. required Widget child,
  2. Color textColor = Colors.white,
  3. Color backgroundColor = Colors.redAccent,
  4. Key? key,
})

Constructor to create a badge with a small size Is a badge without label, sometimes is used to indicate that the icon has a notification

Implementation

const DynamicBadge.small({
  required this.child,
  this.textColor = Colors.white,
  this.backgroundColor = Colors.redAccent,
  super.key,
}): label = '', type = BadgeType.small;