DynamicBadge.small constructor
const
DynamicBadge.small({
- required double childSize,
- AlignmentGeometry? alignment,
- Color? backgroundColor,
- Widget? child,
- Key? key,
Constructor to create a badge with a small size Is a badge without label, sometimes is used to indicate that the icon has a notification
Implementation
const DynamicBadge.small({
required double childSize,
AlignmentGeometry? alignment,
Color? backgroundColor,
Widget? child,
super.key,
}) : _label = '',
_textColor = Colors.white,
_childSize = childSize,
_alignment = alignment ?? Alignment.center,
_backgroundColor = backgroundColor ?? Colors.redAccent,
_child = child ?? const SizedBox();